@@ -7,7 +7,6 @@ from esphome.const import (
     CONF_RGB_ORDER,
     CONF_MAX_REFRESH_RATE,
 )
-from esphome.core import coroutine
 
 CODEOWNERS = ["@OttoWinter"]
 fastled_base_ns = cg.esphome_ns.namespace("fastled_base")
@@ -34,17 +33,16 @@ BASE_SCHEMA = light.ADDRESSABLE_LIGHT_SCHEMA.extend(
 ).extend(cv.COMPONENT_SCHEMA)
 
 
-@coroutine
-def new_fastled_light(config):
+async def new_fastled_light(config):
     var = cg.new_Pvariable(config[CONF_OUTPUT_ID])
-    yield cg.register_component(var, config)
+    await cg.register_component(var, config)
 
     if CONF_MAX_REFRESH_RATE in config:
         cg.add(var.set_max_refresh_rate(config[CONF_MAX_REFRESH_RATE]))
 
-    yield light.register_light(var, config)
+    await light.register_light(var, config)
     # https://github.com/FastLED/FastLED/blob/master/library.json
     # 3.3.3 has an issue on ESP32 with RMT and fastled_clockless:
     # https://github.com/esphome/issues/issues/1375
     cg.add_library("FastLED", "3.3.2")
-    yield var
+    return var
