@@ -5,12 +5,14 @@
 namespace esphome {
 namespace integration {
 
-static const char *TAG = "integration";
+static const char *const TAG = "integration";
 
 void IntegrationSensor::setup() {
   if (this->restore_) {
     this->rtc_ = global_preferences.make_preference<float>(this->get_object_id_hash());
-    this->rtc_.load(&this->result_);
+    float preference_value = 0;
+    this->rtc_.load(&preference_value);
+    this->result_ = preference_value;
   }
 
   this->last_update_ = millis();
