@@ -1,5 +1,7 @@
 #pragma once
 
+#include <utility>
+
 #include "esphome/core/component.h"
 #include "esphome/components/light/addressable_light.h"
 
@@ -8,25 +10,30 @@ namespace partition {
 
 class AddressableSegment {
  public:
-  AddressableSegment(light::LightState *src, int32_t src_offset, int32_t size)
-      : src_(static_cast<light::AddressableLight *>(src->get_output())), src_offset_(src_offset), size_(size) {}
+  AddressableSegment(light::LightState *src, int32_t src_offset, int32_t size, bool reversed)
+      : src_(static_cast<light::AddressableLight *>(src->get_output())),
+        src_offset_(src_offset),
+        size_(size),
+        reversed_(reversed) {}
 
   light::AddressableLight *get_src() const { return this->src_; }
   int32_t get_src_offset() const { return this->src_offset_; }
   int32_t get_size() const { return this->size_; }
   int32_t get_dst_offset() const { return this->dst_offset_; }
   void set_dst_offset(int32_t dst_offset) { this->dst_offset_ = dst_offset; }
+  bool is_reversed() const { return this->reversed_; }
 
  protected:
   light::AddressableLight *src_;
   int32_t src_offset_;
   int32_t size_;
   int32_t dst_offset_;
+  bool reversed_;
 };
 
 class PartitionLightOutput : public light::AddressableLight {
  public:
-  explicit PartitionLightOutput(std::vector<AddressableSegment> segments) : segments_(segments) {
+  explicit PartitionLightOutput(std::vector<AddressableSegment> segments) : segments_(std::move(segments)) {
     int32_t off = 0;
     for (auto &seg : this->segments_) {
       seg.set_dst_offset(off);
@@ -72,7 +79,12 @@ class PartitionLightOutput : public light::AddressableLight {
     // offset within the segment
     int32_t seg_off = index - seg.get_dst_offset();
     // offset within the src
-    int32_t src_off = seg.get_src_offset() + seg_off;
+    int32_t src_off;
+    if (seg.is_reversed())
+      src_off = seg.get_src_offset() + seg.get_size() - seg_off - 1;
+    else
+      src_off = seg.get_src_offset() + seg_off;
+
     auto view = (*seg.get_src())[src_off];
     view.raw_set_color_correction(&this->correction_);
     return view;
