@@ -5,7 +5,7 @@
 namespace esphome {
 namespace tuya {
 
-static const char *TAG = "tuya.fan";
+static const char *const TAG = "tuya.fan";
 
 void TuyaFan::setup() {
   auto traits = fan::FanTraits(this->oscillation_id_.has_value(), this->speed_id_.has_value(),
@@ -13,34 +13,34 @@ void TuyaFan::setup() {
   this->fan_->set_traits(traits);
 
   if (this->speed_id_.has_value()) {
-    this->parent_->register_listener(*this->speed_id_, [this](TuyaDatapoint datapoint) {
+    this->parent_->register_listener(*this->speed_id_, [this](const TuyaDatapoint &datapoint) {
+      ESP_LOGV(TAG, "MCU reported speed of: %d", datapoint.value_enum);
       auto call = this->fan_->make_call();
       if (datapoint.value_enum < this->speed_count_)
         call.set_speed(datapoint.value_enum + 1);
       else
         ESP_LOGCONFIG(TAG, "Speed has invalid value %d", datapoint.value_enum);
-      ESP_LOGD(TAG, "MCU reported speed of: %d", datapoint.value_enum);
       call.perform();
     });
   }
   if (this->switch_id_.has_value()) {
-    this->parent_->register_listener(*this->switch_id_, [this](TuyaDatapoint datapoint) {
+    this->parent_->register_listener(*this->switch_id_, [this](const TuyaDatapoint &datapoint) {
+      ESP_LOGV(TAG, "MCU reported switch is: %s", ONOFF(datapoint.value_bool));
       auto call = this->fan_->make_call();
       call.set_state(datapoint.value_bool);
       call.perform();
-      ESP_LOGD(TAG, "MCU reported switch is: %s", ONOFF(datapoint.value_bool));
     });
   }
   if (this->oscillation_id_.has_value()) {
-    this->parent_->register_listener(*this->oscillation_id_, [this](TuyaDatapoint datapoint) {
+    this->parent_->register_listener(*this->oscillation_id_, [this](const TuyaDatapoint &datapoint) {
+      ESP_LOGV(TAG, "MCU reported oscillation is: %s", ONOFF(datapoint.value_bool));
       auto call = this->fan_->make_call();
       call.set_oscillating(datapoint.value_bool);
       call.perform();
-      ESP_LOGD(TAG, "MCU reported oscillation is: %s", ONOFF(datapoint.value_bool));
     });
   }
   if (this->direction_id_.has_value()) {
-    this->parent_->register_listener(*this->direction_id_, [this](TuyaDatapoint datapoint) {
+    this->parent_->register_listener(*this->direction_id_, [this](const TuyaDatapoint &datapoint) {
       auto call = this->fan_->make_call();
       call.set_direction(datapoint.value_bool ? fan::FAN_DIRECTION_REVERSE : fan::FAN_DIRECTION_FORWARD);
       call.perform();
@@ -66,37 +66,21 @@ void TuyaFan::dump_config() {
 
 void TuyaFan::write_state() {
   if (this->switch_id_.has_value()) {
-    TuyaDatapoint datapoint{};
-    datapoint.id = *this->switch_id_;
-    datapoint.type = TuyaDatapointType::BOOLEAN;
-    datapoint.value_bool = this->fan_->state;
-    this->parent_->set_datapoint_value(datapoint);
-    ESP_LOGD(TAG, "Setting switch: %s", ONOFF(this->fan_->state));
+    ESP_LOGV(TAG, "Setting switch: %s", ONOFF(this->fan_->state));
+    this->parent_->set_datapoint_value(*this->switch_id_, this->fan_->state);
   }
   if (this->oscillation_id_.has_value()) {
-    TuyaDatapoint datapoint{};
-    datapoint.id = *this->oscillation_id_;
-    datapoint.type = TuyaDatapointType::BOOLEAN;
-    datapoint.value_bool = this->fan_->oscillating;
-    this->parent_->set_datapoint_value(datapoint);
-    ESP_LOGD(TAG, "Setting oscillating: %s", ONOFF(this->fan_->oscillating));
+    ESP_LOGV(TAG, "Setting oscillating: %s", ONOFF(this->fan_->oscillating));
+    this->parent_->set_datapoint_value(*this->oscillation_id_, this->fan_->oscillating);
   }
   if (this->direction_id_.has_value()) {
-    TuyaDatapoint datapoint{};
-    datapoint.id = *this->direction_id_;
-    datapoint.type = TuyaDatapointType::BOOLEAN;
     bool enable = this->fan_->direction == fan::FAN_DIRECTION_REVERSE;
-    datapoint.value_bool = enable;
-    this->parent_->set_datapoint_value(datapoint);
-    ESP_LOGD(TAG, "Setting reverse direction: %s", ONOFF(enable));
+    ESP_LOGV(TAG, "Setting reverse direction: %s", ONOFF(enable));
+    this->parent_->set_datapoint_value(*this->direction_id_, enable);
   }
   if (this->speed_id_.has_value()) {
-    TuyaDatapoint datapoint{};
-    datapoint.id = *this->speed_id_;
-    datapoint.type = TuyaDatapointType::ENUM;
-    datapoint.value_enum = this->fan_->speed - 1;
-    ESP_LOGD(TAG, "Setting speed: %d", datapoint.value_enum);
-    this->parent_->set_datapoint_value(datapoint);
+    ESP_LOGV(TAG, "Setting speed: %d", this->fan_->speed);
+    this->parent_->set_datapoint_value(*this->speed_id_, this->fan_->speed - 1);
   }
 }
 
