@@ -1,4 +1,4 @@
-from __future__ import print_function
+from typing import Union, List
 
 import collections
 import io
@@ -7,14 +7,14 @@ import os
 import re
 import subprocess
 import sys
+from pathlib import Path
 
 from esphome import const
-from esphome.py_compat import IS_PY2, decode_text, text_type
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class RegistryEntry(object):
+class RegistryEntry:
     def __init__(self, name, fun, type_id, schema):
         self.name = name
         self.fun = fun
@@ -24,17 +24,19 @@ class RegistryEntry(object):
     @property
     def coroutine_fun(self):
         from esphome.core import coroutine
+
         return coroutine(self.fun)
 
     @property
     def schema(self):
         from esphome.config_validation import Schema
+
         return Schema(self.raw_schema)
 
 
 class Registry(dict):
     def __init__(self, base_schema=None, type_id_key=None):
-        super(Registry, self).__init__()
+        super().__init__()
         self.base_schema = base_schema or {}
         self.type_id_key = type_id_key
 
@@ -60,7 +62,7 @@ def safe_print(message=""):
 
     if CORE.dashboard:
         try:
-            message = message.replace('\033', '\\033')
+            message = message.replace("\033", "\\033")
         except UnicodeEncodeError:
             pass
 
@@ -71,35 +73,35 @@ def safe_print(message=""):
         pass
 
     try:
-        print(message.encode('utf-8', 'backslashreplace'))
+        print(message.encode("utf-8", "backslashreplace"))
     except UnicodeEncodeError:
         try:
-            print(message.encode('ascii', 'backslashreplace'))
+            print(message.encode("ascii", "backslashreplace"))
         except UnicodeEncodeError:
             print("Cannot print line because of invalid locale!")
 
 
 def shlex_quote(s):
     if not s:
-        return u"''"
-    if re.search(r'[^\w@%+=:,./-]', s) is None:
+        return "''"
+    if re.search(r"[^\w@%+=:,./-]", s) is None:
         return s
 
-    return u"'" + s.replace(u"'", u"'\"'\"'") + u"'"
+    return "'" + s.replace("'", "'\"'\"'") + "'"
 
 
-ANSI_ESCAPE = re.compile(r'\033[@-_][0-?]*[ -/]*[@-~]')
+ANSI_ESCAPE = re.compile(r"\033[@-_][0-?]*[ -/]*[@-~]")
 
 
-class RedirectText(object):
+class RedirectText:
     def __init__(self, out, filter_lines=None):
         self._out = out
         if filter_lines is None:
             self._filter_pattern = None
         else:
-            pattern = r'|'.join(r'(?:' + pattern + r')' for pattern in filter_lines)
+            pattern = r"|".join(r"(?:" + pattern + r")" for pattern in filter_lines)
             self._filter_pattern = re.compile(pattern)
-        self._line_buffer = ''
+        self._line_buffer = ""
 
     def __getattr__(self, item):
         return getattr(self._out, item)
@@ -112,29 +114,29 @@ class RedirectText(object):
             # work. The shell we create in the dashboard is not a tty, so python removes
             # all color codes from the resulting stream. We just convert them to something
             # we can easily recognize later here.
-            s = s.replace('\033', '\\033')
+            s = s.replace("\033", "\\033")
         self._out.write(s)
 
     def write(self, s):
-        # s is usually a text_type already (self._out is of type TextIOWrapper)
+        # s is usually a str already (self._out is of type TextIOWrapper)
         # However, s is sometimes also a bytes object in python3. Let's make sure it's a
-        # text_type
+        # str
         # If the conversion fails, we will create an exception, which is okay because we won't
         # be able to print it anyway.
-        text = decode_text(s)
-        assert isinstance(text, text_type)
+        if not isinstance(s, str):
+            s = s.decode()
 
         if self._filter_pattern is not None:
-            self._line_buffer += text
+            self._line_buffer += s
             lines = self._line_buffer.splitlines(True)
             for line in lines:
-                if '\n' not in line and '\r' not in line:
+                if "\n" not in line and "\r" not in line:
                     # Not a complete line, set line buffer
                     self._line_buffer = line
                     break
-                self._line_buffer = ''
+                self._line_buffer = ""
 
-                line_without_ansi = ANSI_ESCAPE.sub('', line)
+                line_without_ansi = ANSI_ESCAPE.sub("", line)
                 line_without_end = line_without_ansi.rstrip()
                 if self._filter_pattern.match(line_without_end) is not None:
                     # Filter pattern matched, ignore the line
@@ -142,7 +144,7 @@ class RedirectText(object):
 
                 self._write_color_replace(line)
         else:
-            self._write_color_replace(text)
+            self._write_color_replace(s)
 
         # write() returns the number of characters written
         # Let's print the number of characters of the original string in order to not confuse
@@ -154,22 +156,35 @@ class RedirectText(object):
         return True
 
 
-def run_external_command(func, *cmd, **kwargs):
+def run_external_command(
+    func, *cmd, capture_stdout: bool = False, filter_lines: str = None
+) -> Union[int, str]:
+    """
+    Run a function from an external package that acts like a main method.
+
+    Temporarily replaces stdin/stderr/stdout, sys.argv and sys.exit handler during the run.
+
+    :param func: Function to execute
+    :param cmd: Command to run as (eg first element of sys.argv)
+    :param capture_stdout: Capture text from stdout and return that.
+    :param filter_lines: Regular expression used to filter captured output.
+    :return: str if `capture_stdout` is set else int exit code.
+
+    """
+
     def mock_exit(return_code):
         raise SystemExit(return_code)
 
     orig_argv = sys.argv
     orig_exit = sys.exit  # mock sys.exit
-    full_cmd = u' '.join(shlex_quote(x) for x in cmd)
-    _LOGGER.info(u"Running:  %s", full_cmd)
+    full_cmd = " ".join(shlex_quote(x) for x in cmd)
+    _LOGGER.info("Running:  %s", full_cmd)
 
-    filter_lines = kwargs.get('filter_lines')
     orig_stdout = sys.stdout
     sys.stdout = RedirectText(sys.stdout, filter_lines=filter_lines)
     orig_stderr = sys.stderr
     sys.stderr = RedirectText(sys.stderr, filter_lines=filter_lines)
 
-    capture_stdout = kwargs.get('capture_stdout', False)
     if capture_stdout:
         cap_stdout = sys.stdout = io.StringIO()
 
@@ -182,8 +197,8 @@ def run_external_command(func, *cmd, **kwargs):
     except SystemExit as err:
         return err.args[0]
     except Exception as err:  # pylint: disable=broad-except
-        _LOGGER.error(u"Running command failed: %s", err)
-        _LOGGER.error(u"Please try running %s locally.", full_cmd)
+        _LOGGER.error("Running command failed: %s", err)
+        _LOGGER.error("Please try running %s locally.", full_cmd)
         return 1
     finally:
         sys.argv = orig_argv
@@ -198,11 +213,11 @@ def run_external_command(func, *cmd, **kwargs):
 
 
 def run_external_process(*cmd, **kwargs):
-    full_cmd = u' '.join(shlex_quote(x) for x in cmd)
-    _LOGGER.info(u"Running:  %s", full_cmd)
-    filter_lines = kwargs.get('filter_lines')
+    full_cmd = " ".join(shlex_quote(x) for x in cmd)
+    _LOGGER.info("Running:  %s", full_cmd)
+    filter_lines = kwargs.get("filter_lines")
 
-    capture_stdout = kwargs.get('capture_stdout', False)
+    capture_stdout = kwargs.get("capture_stdout", False)
     if capture_stdout:
         sub_stdout = io.BytesIO()
     else:
@@ -211,12 +226,10 @@ def run_external_process(*cmd, **kwargs):
     sub_stderr = RedirectText(sys.stderr, filter_lines=filter_lines)
 
     try:
-        return subprocess.call(cmd,
-                               stdout=sub_stdout,
-                               stderr=sub_stderr)
+        return subprocess.call(cmd, stdout=sub_stdout, stderr=sub_stderr)
     except Exception as err:  # pylint: disable=broad-except
-        _LOGGER.error(u"Running command failed: %s", err)
-        _LOGGER.error(u"Please try running %s locally.", full_cmd)
+        _LOGGER.error("Running command failed: %s", err)
+        _LOGGER.error("Please try running %s locally.", full_cmd)
         return 1
     finally:
         if capture_stdout:
@@ -225,7 +238,7 @@ def run_external_process(*cmd, **kwargs):
 
 
 def is_dev_esphome_version():
-    return 'dev' in const.__version__
+    return "dev" in const.__version__
 
 
 # Custom OrderedDict with nicer repr method for debugging
@@ -233,29 +246,6 @@ class OrderedDict(collections.OrderedDict):
     def __repr__(self):
         return dict(self).__repr__()
 
-    def move_to_end(self, key, last=True):
-        if IS_PY2:
-            if len(self) == 1:
-                return
-            if last:
-                # When moving to end, just pop and re-add
-                val = self.pop(key)
-                self[key] = val
-            else:
-                # When moving to front, use internals here
-                # https://stackoverflow.com/a/16664932
-                root = self._OrderedDict__root  # pylint: disable=no-member
-                first = root[1]
-                link = self._OrderedDict__map[key]  # pylint: disable=no-member
-                link_prev, link_next, _ = link
-                link_prev[1] = link_next
-                link_next[0] = link_prev
-                link[0] = root
-                link[1] = first
-                root[1] = first[0] = link
-        else:
-            super(OrderedDict, self).move_to_end(key, last=last)  # pylint: disable=no-member
-
 
 def list_yaml_files(folder):
     files = filter_yaml_files([os.path.join(folder, p) for p in os.listdir(folder)])
@@ -264,7 +254,39 @@ def list_yaml_files(folder):
 
 
 def filter_yaml_files(files):
-    files = [f for f in files if os.path.splitext(f)[1] == '.yaml']
-    files = [f for f in files if os.path.basename(f) != 'secrets.yaml']
-    files = [f for f in files if not os.path.basename(f).startswith('.')]
+    files = [f for f in files if os.path.splitext(f)[1] == ".yaml"]
+    files = [f for f in files if os.path.basename(f) != "secrets.yaml"]
+    files = [f for f in files if not os.path.basename(f).startswith(".")]
     return files
+
+
+class SerialPort:
+    def __init__(self, path: str, description: str):
+        self.path = path
+        self.description = description
+
+
+# from https://github.com/pyserial/pyserial/blob/master/serial/tools/list_ports.py
+def get_serial_ports() -> List[SerialPort]:
+    from serial.tools.list_ports import comports
+
+    result = []
+    for port, desc, info in comports(include_links=True):
+        if not port:
+            continue
+        if "VID:PID" in info:
+            result.append(SerialPort(path=port, description=desc))
+    # Also add objects in /dev/serial/by-id/
+    # ref: https://github.com/esphome/issues/issues/1346
+
+    by_id_path = Path("/dev/serial/by-id")
+    if sys.platform.lower().startswith("linux") and by_id_path.exists():
+        from serial.tools.list_ports_linux import SysFS
+
+        for path in by_id_path.glob("*"):
+            device = SysFS(path)
+            if device.subsystem == "platform":
+                result.append(SerialPort(path=str(path), description=info[1]))
+
+    result.sort(key=lambda x: x.path)
+    return result
